==> libcamera-docs-0.0.4-1-aarch64.pkg.tar.xz: usr/share/doc/libcamera/api-html/search/variables_12.js <==
var searchData=
[
  ['temperaturek_0',['temperatureK',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a5d3c94ae89f0bcea6ef49507f800a639',1,'libcamera::ipa::ipu3::IPAActiveState']]],
  ['testpatternmode_1',['TestPatternMode',['../namespacelibcamera_1_1controls_1_1draft.html#a74be8e3ea7b91fedda2c24a48532dbfb',1,'libcamera::controls::draft']]],
  ['testpatternmodes_2',['testPatternModes',['../structlibcamera_1_1CameraSensorProperties.html#ab7c00695ac7966e8c1b82be681a9f12f',1,'libcamera::CameraSensorProperties']]],
  ['testpatternmodevalues_3',['TestPatternModeValues',['../namespacelibcamera_1_1controls_1_1draft.html#ac9b1d93e0727985fa7895b7501a2a915',1,'libcamera::controls::draft']]],
  ['timeout_4',['timeout',['../classlibcamera_1_1Timer.html#aa5cf441be2e6686c96e085de2ef47d7a',1,'libcamera::Timer']]],
  ['timestamp_5',['timestamp',['../structlibcamera_1_1FrameMetadata.html#a08999a7c7b62eeba0a36d352c314bc65',1,'libcamera::FrameMetadata']]],
  ['tonemapping_6',['toneMapping',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a018463188c83554909e9d49d7d746ca6',1,'libcamera::ipa::ipu3::IPAActiveState']]],
  ['transferfunction_7',['transferFunction',['../classlibcamera_1_1ColorSpace.html#aad157363bb71e59a7ffcada42a501e2c',1,'libcamera::ColorSpace']]],
  ['transform_8',['transform',['../classlibcamera_1_1CameraConfiguration.html#acd22786c435f21a2166510be47d8510b',1,'libcamera::CameraConfiguration::transform()'],['../structlibcamera_1_1V4L2SubdeviceFormat.html#af541ff53606057574dba2747f2d12ad3',1,'libcamera::V4L2SubdeviceFormat::transform()']]],
  ['type_9',['type',['../structlibcamera_1_1ipa__control__value__entry.html#a001952000014292562b825339b26b0ce',1,'libcamera::ipa_control_value_entry::type()'],['../structlibcamera_1_1ipa__control__info__entry.html#aa478c97c6471f027789e98d67c25f678',1,'libcamera::ipa_control_info_entry::type()']]]
];

==> libcamera-docs-0.0.5-1-aarch64.pkg.tar.xz: usr/share/doc/libcamera/api-html/search/variables_12.js <==
var searchData=
[
  ['temperaturek_0',['temperatureK',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a5d3c94ae89f0bcea6ef49507f800a639',1,'libcamera::ipa::ipu3::IPAActiveState']]],
  ['testpatternmode_1',['TestPatternMode',['../namespacelibcamera_1_1controls_1_1draft.html#a74be8e3ea7b91fedda2c24a48532dbfb',1,'libcamera::controls::draft']]],
  ['testpatternmodes_2',['testPatternModes',['../structlibcamera_1_1CameraSensorProperties.html#ab7c00695ac7966e8c1b82be681a9f12f',1,'libcamera::CameraSensorProperties']]],
  ['testpatternmodevalues_3',['TestPatternModeValues',['../namespacelibcamera_1_1controls_1_1draft.html#ac9b1d93e0727985fa7895b7501a2a915',1,'libcamera::controls::draft']]],
  ['timeout_4',['timeout',['../classlibcamera_1_1Timer.html#aa5cf441be2e6686c96e085de2ef47d7a',1,'libcamera::Timer']]],
  ['timestamp_5',['timestamp',['../structlibcamera_1_1FrameMetadata.html#a08999a7c7b62eeba0a36d352c314bc65',1,'libcamera::FrameMetadata']]],
  ['tonemapping_6',['toneMapping',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a018463188c83554909e9d49d7d746ca6',1,'libcamera::ipa::ipu3::IPAActiveState']]],
  ['transferfunction_7',['transferFunction',['../classlibcamera_1_1ColorSpace.html#aad157363bb71e59a7ffcada42a501e2c',1,'libcamera::ColorSpace']]],
  ['transform_8',['transform',['../classlibcamera_1_1CameraConfiguration.html#acd22786c435f21a2166510be47d8510b',1,'libcamera::CameraConfiguration']]],
  ['type_9',['type',['../structlibcamera_1_1ipa__control__value__entry.html#a001952000014292562b825339b26b0ce',1,'libcamera::ipa_control_value_entry::type()'],['../structlibcamera_1_1ipa__control__info__entry.html#aa478c97c6471f027789e98d67c25f678',1,'libcamera::ipa_control_info_entry::type()']]]
];
